@@ -25,6 +25,8 @@ class Country(object):
     :ivar country: :py:class:`geoip2.records.Country` object representing
       country data for the requested IP address. This record represents the
       country where MaxMind believes the IP is located in.
+    :ivar maxmind: :py:class:`geoip2.records.MaxMind` object with
+      information related to your MaxMind account.
     :ivar registered_country: :py:class:`geoip2.records.Country` object
       representing the registered country data for the requested IP address.
       This record represents the country where the ISP has registered a given
@@ -56,6 +58,9 @@ class Country(object):
                                                 **raw_response.get(
                                                 'represented_country', {}))
 
+        self.maxmind = \
+            geoip2.records.MaxMind(**raw_response.get('maxmind', {}))
+
         self.traits = geoip2.records.Traits(**raw_response.get('traits', {}))
         self.raw = raw_response
 
@@ -72,6 +77,8 @@ class City(Country):
       country where MaxMind believes the IP is located in.
     :ivar location: :py:class:`geoip2.records.Location` object
       representing country data for the requested IP address.
+    :ivar maxmind: :py:class:`geoip2.records.MaxMind` object with
+      information related to your MaxMind account.
     :ivar region: :py:class:`geoip2.records.Region` object representing
       country data for the requested IP address.
     :ivar registered_country: :py:class:`geoip2.records.Country` object
@@ -112,6 +119,8 @@ class CityISPOrg(City):
       country where MaxMind believes the IP is located in.
     :ivar location: :py:class:`geoip2.records.Location` object
       representing country data for the requested IP address.
+    :ivar maxmind: :py:class:`geoip2.records.MaxMind` object with
+      information related to your MaxMind account.
     :ivar region: :py:class:`geoip2.records.Region` object representing
       country data for the requested IP address.
     :ivar registered_country: :py:class`geoip2.records.Country` object
@@ -141,6 +150,8 @@ class Omni(CityISPOrg):
       country where MaxMind believes the IP is located in.
     :ivar location: :py:class:`geoip2.records.Location` object
       representing country data for the requested IP address.
+    :ivar maxmind: :py:class:`geoip2.records.MaxMind` object with
+      information related to your MaxMind account.
     :ivar region: :py:class:`geoip2.records.Region` object representing
       country data for the requested IP address.
     :ivar registered_country: :py:class:`geoip2.records.Country` object
