@@ -75,9 +75,8 @@ class Continent(PlaceRecord):
 
     Attributes:
 
-    :ivar continent_code: A two character continent code
-      like "NA" (North America) or "OC" (Oceania). This attribute is returned
-      by all end points.
+    :ivar code: A two character continent code like "NA" (North America)
+      or "OC" (Oceania). This attribute is returned by all end points.
     :ivar geoname_id: The GeoName ID for the continent. This
       attribute is returned by all end points.
     :ivar name: Returns the name of the continent based on the languages list
@@ -86,7 +85,7 @@ class Continent(PlaceRecord):
       and the values are names. This attribute is returned by all end points.
 
     """
-    _valid_attributes = set(['continent_code', 'geoname_id', 'names'])
+    _valid_attributes = set(['code', 'geoname_id', 'names'])
 
 
 class Country(PlaceRecord):
@@ -182,6 +181,18 @@ class Location(Record):
                              'metro_code', 'postal_code', 'postal_confidence',
                              'time_zone'])
 
+class MaxMind(Record):
+    """Contains data related to your MaxMind account
+
+    This record is returned by all the end points.
+
+    Attributes:
+
+    :ivar queries_remaining: The number of remaining queries you have
+      for the end point you are calling.
+
+    """
+    _valid_attributes = set(['queries_remaining'])
 
 class Postal(Record):
     """Contains data for the postal record associated with an IP address
