@@ -100,6 +100,14 @@ import requests
 from requests.utils import default_user_agent
 from .errors import GeoIP2Error, HTTPError, WebServiceError
 
+import sys
+
+if sys.version_info[0] == 2 or (sys.version_info[0] == 3
+                                and sys.version_info[1] < 3):
+    import ipaddr as ipaddress #pylint:disable=F0401
+    ipaddress.ip_address = ipaddress.IPAddress
+else:
+    import ipaddress #pylint:disable=F0401
 
 class Client(object):
     """This method creates a new client object.
@@ -129,17 +137,19 @@ class Client(object):
       data in "en". If you do not include this language, the name property
       may end up returning None even when the record hass an English name.
 
-      Currently, the valid list of language codes is:
+      Currently, the valid language codes are:
 
+      * de -- German
       * en -- English names may still include accented characters if that is
         the accepted spelling in English. In other words, English does not
         mean ASCII.
+      * es -- Spanish
+      * fr -- French
       * ja -- Japanese
+      * pt-BR -- Brazilian Portuguese
       * ru -- Russian
       * zh-CN -- Simplified Chinese.
 
-      Passing any other language code will result in an error.
-
     """
 
     def __init__(self, user_id, license_key, host='geoip.maxmind.com',
@@ -202,6 +212,8 @@ class Client(object):
         return self._response_for('omni', geoip2.models.Omni, ip_address)
 
     def _response_for(self, path, model_class, ip_address):
+        if ip_address != 'me':
+            ip_address = str(ipaddress.ip_address(ip_address))
         uri = '/'.join([self._base_uri, path, ip_address])
         response = requests.get(uri, auth=(self.user_id, self.license_key),
                                 headers={'Accept': 'application/json',
